==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/ronportal/kapacity/kapacitycontroller.php <==
<?php
/**
 * stanislav.elbl, 16.07.2015
 * Planovani kapacit
 */


namespace RonPortal\Kapacity;

use Exception;
use Ron\Controls\ComboBox;
use Ron\DateUtils;
use Ron\DB\DBException;
use Ron\Http\HtmlHeaders;
use Ron\Http\HttpResponse;
use Ron\MessageManager;
use Ron\MVC\HttpController;
use Ron\MVC\Model;
use Ron\MVC\OutputObject;
use Ron\MVC\Redirect;
use Ron\MVC\ViewObject;
use Ron\StringUtils;
use Ron\TextManager;
use RonPortal\NastaveniUzivatele;
use RonPortal\NeniPravoException;
use RonPortal\Obdobi;
use RonPortal\Prava;
use RonPortal\RonPortalSession;
use RonPortal\RonPortalSettings;
use RonPortal\Rozdeleni;
use RonPortal\System\Report;
use RonPortal\System\ReportOutputObject;
use RonPortal\TypRozdeleni;
use RonPortal\User;

class KapacityController extends HttpController
{

    protected $database;

    public function __construct($database)
    {
        $this->database = $database;
    }


    public static function getZobrazitSkuteneAbsence()
    {
        return RonPortalSession::getValue('skutecneabsence'); // nacteno z cookie
    }


    /**
     * @throws Exception
     */
    public function report($utf8)
    {
        $result = new ReportOutputObject();
        $result->loadReportFromGet($this ->database, ['PrehledKapacit', 'PlanovaniKapacit'], $utf8, 'PlanovaniKapacit'); // treti parametr z duvodu kompatibility

        $kodRozdeleni = $utf8 ? StringUtils::fromUTF8($_GET['rozdeleni']) : $_GET['rozdeleni'];
        $kodRozdeleni2 = $utf8 ? StringUtils::fromUTF8($_GET['rozdeleni2']) : $_GET['rozdeleni2'];

        if ($kodRozdeleni != '') {
            $rozdeleni = Rozdeleni::loadRozdeleni($this ->database, KapacitySettings::typRozdeleniProVyber(), $kodRozdeleni);
            $result ->nastavRozdeleni(true, $rozdeleni, false); // vyresit vcetne podrizenych
        }

        if ($kodRozdeleni2 != '') {
            $rozdeleni = Rozdeleni::loadRozdeleni($this ->database, RonPortalSettings::getIntValue(RonPortalSettings::ROZDELENI2_TYP), $kodRozdeleni2);
            $result ->nastavRozdeleni2(true, $rozdeleni, false); // vyresit vcetne podrizenych
        }

        if (isset($_GET['idpp'])) {
            $result->stringParams['IdPP'] = $_GET['idpp'];
        }

        $obdobi = Obdobi::vratObdobi($this ->database, 'ADS', DateUtils::urlStringToDate($_GET['obdobi']));
        $result ->nastavObdobi(0, $obdobi ->zacatek, $obdobi ->konec, $obdobi ->popis);

        if (isset($_GET['den'])) {
            $result->dateParams['den'] = $_GET['den'];
        }

        return $result;
    }


    /**
     * @param int $pocatekObdobi
     * @return SchvaleniPodminekPlanovani
     * @throws DBException
     */
    private function nactiSchvaleniPoctu($pocatekObdobi)
    {
        // overi, jestli uz jsou schvalene podminky planovani nastavenym levelem
        $rozdeleni = $_GET['rozdeleni'] ?: RonPortalSession::rozdeleni();

        return SchvaleniPodminekPlanovani::nactiSchvaleni($this->database, $pocatekObdobi, KapacitySettings::typRozdeleniProVyber(), $rozdeleni);
    }

    /**
     * @param int $pocatekObdobi
     * @return SchvaleniKapacitRozdeleni
     * @throws DBException
     */
    private function nactiSchvaleniRozdeleni($pocatekObdobi)
    {
        $rozdeleni = $_GET['rozdeleni'] ?: RonPortalSession::rozdeleni();

        return SchvaleniKapacitRozdeleni::nactiSchvaleni($this ->database, $pocatekObdobi, KapacitySettings::typRozdeleniProVyber(), $rozdeleni);
    }


    /**
     * Zobrazi aktivni planovani kapacit
     * @param bool $planovaniPoSlotech
     * @param bool $rezimUprav
     * @return string
     * @throws Exception
     */
    public function aktivniPlanovani($planovaniPoSlotech, $rezimUprav)
    {
        $vyzadovanoSchvaleniPoctu = Prava::vratPrava('kapacity_edit')->priznak2;

        $pocatekObdobi = $_GET['obdobi'] ? DateUtils::urlStringToDate($_GET['obdobi']) : RonPortalSession::obdobi();

        if ($vyzadovanoSchvaleniPoctu) {
            // overi, jestli uz jsou schvalene podminky planovani nastavenym levelem
            $schvaleniPoctu = $this ->nactiSchvaleniPoctu($pocatekObdobi);

            if (!$schvaleniPoctu->lzePlanovatDen(DateUtils::lastDayOfMonth($schvaleniPoctu ->pocatekObdobi))) {
                throw new Exception(\Ron\ronText('Pocty_zamestnancu_jeste_nejsou_schvaleny'));
            }
        }

        if (!isset($rezimUprav)  &&  RonPortalSettings::getIntValue('kapacity_rezimuprav')  &&  RonPortalSettings::getIntValue('kapacity_minschvaleniproupravy')) {
            // nastavi rezim automaticky podle toho, jestli je uz schvaleno
            $schvaleniKapacit = $this ->nactiSchvaleniRozdeleni($pocatekObdobi);

            if ($schvaleniKapacit ->getSchvaleniPuvodnihoPlanu() >= DateUtils::lastDayOfMonth($pocatekObdobi)) {
                $rezimUprav = true;
            }
        }

        if (RonPortalSettings::getIntValue(KapacitySettings::KAPACITY_TYP_ROZDELENI2)) {
            $typRozdeleni2 = TypRozdeleni::getTypRozdeleni($this->database, RonPortalSettings::getIntValue(KapacitySettings::KAPACITY_TYP_ROZDELENI2));
            Model::addData('typRozdeleni2', $typRozdeleni2);
        }

        // sestavy -
        $reportList = Report::loadFormReports($this->database, ['PlanovaniKapacit', 'PrehledKapacit'], 'PlanovaniKapacit'); // treti parametr z duvodu kompatibility
        Model::addData('reportList', $reportList);

        $vychoziTypDokumentu = NastaveniUzivatele::getUserSettingsItem($this->database, 'pk_typdokumentu', 0);

        $combo = new ComboBox('typ');
        $combo->dataTypeComparison = false;
        $combo->className = 'form-control planovani_detailkod';
        $combo->htmlParams = ['id' => 'planovani_detail_typ_dokumentu'];
        $combo->loadData($this->database, 'SELECT Kod, Popis FROM TypDokumentu WHERE ZobrazitNaIntrawebu = 1 ORDER BY Kod', $vychoziTypDokumentu);
        Model::addData('typDokumentuComboBox', $combo);

        Model::addData('sirkaBunky', KapacitySettings::sirkaBunky($this->database));
        Model::addData('vyskaBunky', KapacitySettings::vyskaBunky($this->database));
        Model::addData('provadetKontroly', KapacitySettings::pouzivatKontrolyPlanovani());
        Model::addData('database', $this->database);

        Model::addData('planovaniPoSlotech', $planovaniPoSlotech);
        Model::addData('rezimUprav', $rezimUprav);

        // aktivni rezim
        return 'ronportal/kapacity/view_planovani.php';
    }


    /**
     * @return null|Redirect
     */
    public function ulozitSchvaleni($menuId)
    {
        if (!RonPortalSettings::getIntValue(RonPortalSettings::KAPACITY_EDITACE)) {
            return null;
        }

        try {
            SchvaleniKapacitForm::provedSchvaleni($this->database);
            //$this->data->provedSchvaleni();

            return new Redirect(null, 'menuid=' . $menuId);
        } catch (Exception $e) {
            MessageManager::addErrorMessage($e);
        }

        return null;
    }


    private function planovaniPodminek()
    {
        return new Redirect(null, 'menuid=planovanipodminek');
    }


    private function kapacityDleSmen()
    {
        $viewObject = new KapacityDleSmenView($this ->database);
        $viewObject ->load();

        if (User::isAuthenticated()) {
            return $viewObject;
        }

        Model::addViewObject($viewObject);
        return 'view/appview_nouser.php';
    }

    /**
     * @param string $action
     * @return Redirect|OutputObject|ViewObject|string
     * @throws NeniPravoException
     * @throws \Exception
     */
    public function handleAction($action)
    {
        TextManager::getInstance() ->loadStrings('kapacity.ini');
        HtmlHeaders::getInstance() ->addScript('script/kapacity_html.js');
        $this ->addTranslationsScript('kapacity');
        HtmlHeaders::getInstance() ->addCss('css/s_kapacity.css', '?ver=' . HtmlHeaders::getInstance() ->versionId);
        HtmlHeaders::getInstance() ->setTitle(\Ron\ronText('RON_Portal') . ' - ' . \Ron\ronText('Planovani_kapacit'));

        if (!User::isAuthenticated()) {
            if ($action !== 'kapacitydlesmen'  ||  !RonPortalSettings::getIntValue('kapacitydlesmen_bezprihlaseni')) {
                throw new NeniPravoException();
            }

            return $this ->kapacityDleSmen();
        }

        if (isset($_GET['rezim'])) {
            NastaveniUzivatele::setUserSettingsItem($this->database, 'kapacity_rezimuprav', (int)$_GET['rezim'],
                RonPortalSettings::getIntValue('kapacity_rezim'));
        }

        $rezim = (int)NastaveniUzivatele::getUserSettingsItem($this ->database, 'kapacity_rezimuprav', RonPortalSettings::getIntValue('kapacity_rezim'));

        if ($rezim === 5) {
            return $this ->planovaniPodminek();
        }

        if (isset($_GET['action'])) {
            switch ($_GET['action']) {
                case 'translations' :
                    return $this ->translations();

                case 'report' :
                    return $this ->report(false);
                case 'reporta' :    // reporty v aktivnim rezimu - url generuje javascript, takze nektere hodnoty jsou v utf8
                    return $this ->report(true);
            }
        }

        if (isset($_POST['ulozitschvaleni'])) {
            $result = $this ->ulozitSchvaleni($action);
            if ($result) {
                return $result;
            }
        }

        if (isset($_GET['skutecneabsence'])) {
            HttpResponse::setCookie('ads_skutecneabsence', (int)$_GET['skutecneabsence'], time() + 30000000);
            $_SESSION['skutecneabsence'] = (int)$_GET['skutecneabsence'];
        } else {
            $_SESSION['skutecneabsence'] = isset($_COOKIE['ads_skutecneabsence']) ? (int)$_COOKIE['ads_skutecneabsence'] : 0;
        }

        try {
            $rezimUprav = null;

            if (isset($_GET['rezimUprav'])) {
                $rezimUprav = (int)$_GET['rezimUprav'];
            }

            switch ($action) {
                case 'planovanikapacit':
                    return $this->aktivniPlanovani(false, $rezimUprav);

                case 'planovanislotu':
                    return $this->aktivniPlanovani(true, $rezimUprav);
            }
        } catch (Exception $e) {
            MessageManager::addErrorMessage($e);
        }

        if ($action === 'kapacitydlesmen'  ||  $rezim === 3) {
            // prehled podle smen
            return $this ->kapacityDleSmen();
        }

        // pasivni zobrazeni
        HttpResponse::setCookieAndSession('kapacity_sort', 'kapacity_sort', false, true); // GET

        $viewObject = new PrehledKapacitView($this ->database);
        $viewObject ->load();

        return  $viewObject;
    }

}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2302_169.zip: ronportal/ronportal/kapacity/kapacitycontroller.php <==
<?php
/**
 * stanislav.elbl, 16.07.2015
 * Planovani kapacit
 */


namespace RonPortal\Kapacity;

use Exception;
use Ron\Controls\ComboBox;
use Ron\DateUtils;
use Ron\DB\DBException;
use Ron\Http\HtmlHeaders;
use Ron\Http\HttpResponse;
use Ron\MessageManager;
use Ron\MVC\HttpController;
use Ron\MVC\Model;
use Ron\MVC\OutputObject;
use Ron\MVC\Redirect;
use Ron\MVC\ViewObject;
use Ron\StringUtils;
use Ron\TextManager;
use RonPortal\NastaveniUzivatele;
use RonPortal\NeniPravoException;
use RonPortal\Obdobi;
use RonPortal\Prava;
use RonPortal\RonPortalSession;
use RonPortal\RonPortalSettings;
use RonPortal\Rozdeleni;
use RonPortal\System\Report;
use RonPortal\System\ReportOutputObject;
use RonPortal\TypRozdeleni;
use RonPortal\User;

class KapacityController extends HttpController
{

    protected $database;

    public function __construct($database)
    {
        $this->database = $database;
    }


    public static function getZobrazitSkuteneAbsence()
    {
        return RonPortalSession::getValue('skutecneabsence'); // nacteno z cookie
    }


    /**
     * @param bool $utf8
     * @return ReportOutputObject
     * @throws Exception
     */
    public function report($utf8)
    {
        $result = new ReportOutputObject();
        $result->loadReportFromGet($this ->database, ['PrehledKapacit', 'PlanovaniKapacit'], $utf8, 'PlanovaniKapacit'); // treti parametr z duvodu kompatibility

        $kodRozdeleni = $utf8 ? StringUtils::fromUTF8($_GET['rozdeleni']) : $_GET['rozdeleni'];
        $kodRozdeleni2 = $utf8 ? StringUtils::fromUTF8($_GET['rozdeleni2']) : $_GET['rozdeleni2'];

        if ($kodRozdeleni != '') {
            $rozdeleni = Rozdeleni::loadRozdeleni($this ->database, KapacitySettings::typRozdeleniProVyber(), $kodRozdeleni);
            $result ->nastavRozdeleni(true, $rozdeleni, false); // vyresit vcetne podrizenych
        }

        if ($kodRozdeleni2 != '') {
            $rozdeleni = Rozdeleni::loadRozdeleni($this ->database, RonPortalSettings::getIntValue(RonPortalSettings::ROZDELENI2_TYP), $kodRozdeleni2);
            $result ->nastavRozdeleni2(true, $rozdeleni, false); // vyresit vcetne podrizenych
        }

        if (isset($_GET['idpp'])) {
            $result->stringParams['IdPP'] = $_GET['idpp'];
        }

        $obdobi = Obdobi::vratObdobi($this ->database, 'ADS', DateUtils::urlStringToDate($_GET['obdobi']));
        $result ->nastavObdobi(0, $obdobi ->zacatek, $obdobi ->konec, $obdobi ->popis);

        if (isset($_GET['den'])) {
            $result->dateParams['den'] = $_GET['den'];
        }

        return $result;
    }


    /**
     * @param int $pocatekObdobi
     * @return SchvaleniPodminekPlanovani
     * @throws DBException
     */
    private function nactiSchvaleniPoctu($pocatekObdobi)
    {
        // overi, jestli uz jsou schvalene podminky planovani nastavenym levelem
        $rozdeleni = $_GET['rozdeleni'] ?: RonPortalSession::rozdeleni();

        return SchvaleniPodminekPlanovani::nactiSchvaleni($this->database, $pocatekObdobi, KapacitySettings::typRozdeleniProVyber(), $rozdeleni);
    }

    /**
     * @param int $pocatekObdobi
     * @return SchvaleniKapacitRozdeleni
     * @throws DBException
     */
    private function nactiSchvaleniRozdeleni($pocatekObdobi)
    {
        $rozdeleni = $_GET['rozdeleni'] ?: RonPortalSession::rozdeleni();

        return SchvaleniKapacitRozdeleni::nactiSchvaleni($this ->database, $pocatekObdobi, KapacitySettings::typRozdeleniProVyber(), $rozdeleni);
    }


    /**
     * Zobrazi aktivni planovani kapacit
     * @param bool $planovaniPoSlotech
     * @param bool $rezimUprav
     * @return string
     * @throws Exception
     */
    public function aktivniPlanovani($planovaniPoSlotech, $rezimUprav)
    {
        $vyzadovanoSchvaleniPoctu = Prava::vratPrava('kapacity_edit')->priznak2;

        $pocatekObdobi = $_GET['obdobi'] ? DateUtils::urlStringToDate($_GET['obdobi']) : RonPortalSession::obdobi();

        if ($vyzadovanoSchvaleniPoctu) {
            // overi, jestli uz jsou schvalene podminky planovani nastavenym levelem
            $schvaleniPoctu = $this ->nactiSchvaleniPoctu($pocatekObdobi);

            if (!$schvaleniPoctu->lzePlanovatDen(DateUtils::lastDayOfMonth($schvaleniPoctu ->pocatekObdobi))) {
                throw new Exception(\Ron\ronText('Pocty_zamestnancu_jeste_nejsou_schvaleny'));
            }
        }

        if (!isset($rezimUprav)  &&  RonPortalSettings::getIntValue('kapacity_rezimuprav')  &&  RonPortalSettings::getIntValue('kapacity_minschvaleniproupravy')) {
            // nastavi rezim automaticky podle toho, jestli je uz schvaleno
            $schvaleniKapacit = $this ->nactiSchvaleniRozdeleni($pocatekObdobi);

            if ($schvaleniKapacit ->getSchvaleniPuvodnihoPlanu() >= DateUtils::lastDayOfMonth($pocatekObdobi)) {
                $rezimUprav = true;
            }
        }

        if (RonPortalSettings::getIntValue(KapacitySettings::KAPACITY_TYP_ROZDELENI2)) {
            $typRozdeleni2 = TypRozdeleni::getTypRozdeleni($this->database, RonPortalSettings::getIntValue(KapacitySettings::KAPACITY_TYP_ROZDELENI2));
            Model::addData('typRozdeleni2', $typRozdeleni2);
        }

        // sestavy -
        $reportList = Report::loadFormReports($this->database, ['PlanovaniKapacit', 'PrehledKapacit'], 'PlanovaniKapacit'); // treti parametr z duvodu kompatibility
        Model::addData('reportList', $reportList);

        $vychoziTypDokumentu = NastaveniUzivatele::getUserSettingsItem($this->database, 'pk_typdokumentu', 0);

        $combo = new ComboBox('typ');
        $combo->dataTypeComparison = false;
        $combo->className = 'form-control planovani_detailkod';
        $combo->htmlParams = ['id' => 'planovani_detail_typ_dokumentu'];
        $combo->loadData($this->database, 'SELECT Kod, Popis FROM TypDokumentu WHERE ZobrazitNaIntrawebu = 1 ORDER BY Kod', $vychoziTypDokumentu);
        Model::addData('typDokumentuComboBox', $combo);

        Model::addData('sirkaBunky', KapacitySettings::sirkaBunky($this->database));
        Model::addData('vyskaBunky', KapacitySettings::vyskaBunky($this->database));
        Model::addData('provadetKontroly', KapacitySettings::pouzivatKontrolyPlanovani());
        Model::addData('database', $this->database);

        Model::addData('planovaniPoSlotech', $planovaniPoSlotech);
        Model::addData('rezimUprav', $rezimUprav);

        // aktivni rezim
        return 'ronportal/kapacity/view_planovani.php';
    }


    /**
     * @param string $menuId
     * @return null|Redirect
     */
    public function ulozitSchvaleni($menuId)
    {
        if (!RonPortalSettings::getIntValue(KapacitySettings::KAPACITY_EDITACE)) {
            return null;
        }

        try {
            SchvaleniKapacitForm::provedSchvaleni($this->database);
            //$this->data->provedSchvaleni();

            return new Redirect(null, 'menuid=' . $menuId);
        } catch (Exception $e) {
            MessageManager::addErrorMessage($e);
        }

        return null;
    }


    private function planovaniPodminek()
    {
        return new Redirect(null, 'menuid=planovanipodminek');
    }


    private function kapacityDleSmen()
    {
        $viewObject = new KapacityDleSmenView($this ->database);
        $viewObject ->load();

        if (User::isAuthenticated()) {
            return $viewObject;
        }

        Model::addViewObject($viewObject);
        return 'view/appview_nouser.php';
    }

    /**
     * @param string $action
     * @return Redirect|OutputObject|ViewObject|string
     * @throws NeniPravoException
     * @throws \Exception
     */
    public function handleAction($action)
    {
        TextManager::getInstance() ->loadStrings('kapacity.ini');
        HtmlHeaders::getInstance() ->addScript('script/kapacity_html.js');
        $this ->addTranslationsScript('kapacity');
        HtmlHeaders::getInstance() ->addCss('css/s_kapacity.css');
        HtmlHeaders::getInstance() ->setTitle(\Ron\ronText('RON_Portal') . ' - ' . \Ron\ronText('Planovani_kapacit'));

        if (!User::isAuthenticated()) {
            if ($action !== 'kapacitydlesmen'  ||  !RonPortalSettings::getIntValue('kapacitydlesmen_bezprihlaseni')) {
                throw new NeniPravoException();
            }

            return $this ->kapacityDleSmen();
        }

        if (isset($_GET['rezim'])) {
            NastaveniUzivatele::setUserSettingsItem($this->database, 'kapacity_rezimuprav', (int)$_GET['rezim'],
                RonPortalSettings::getIntValue('kapacity_rezim'));
        }

        $rezim = (int)NastaveniUzivatele::getUserSettingsItem($this ->database, 'kapacity_rezimuprav', RonPortalSettings::getIntValue('kapacity_rezim'));

        if ($rezim === 5) {
            return $this ->planovaniPodminek();
        }

        if (isset($_GET['action'])) {
            switch ($_GET['action']) {
                case 'translations' :
                    return $this ->translations();

                case 'report' :
                    return $this ->report(false);
                case 'reporta' :    // reporty v aktivnim rezimu - url generuje javascript, takze nektere hodnoty jsou v utf8
                    return $this ->report(true);
            }
        }

        if (isset($_POST['ulozitschvaleni'])) {
            $result = $this ->ulozitSchvaleni($action);
            if ($result) {
                return $result;
            }
        } else if (isset($_POST['neulozitschvaleni'])) {
            return new Redirect(null, '?menuid=' . $action . '#schvalovani');
        }

        if (isset($_GET['skutecneabsence'])) {
            HttpResponse::setCookie('ads_skutecneabsence', (int)$_GET['skutecneabsence'], time() + 30000000);
            $_SESSION['skutecneabsence'] = (int)$_GET['skutecneabsence'];
        } else {
            $_SESSION['skutecneabsence'] = isset($_COOKIE['ads_skutecneabsence']) ? (int)$_COOKIE['ads_skutecneabsence'] : 0;
        }

        try {
            $rezimUprav = null;

            if (isset($_GET['rezimUprav'])) {
                $rezimUprav = (int)$_GET['rezimUprav'];
            }

            switch ($action) {
                case 'planovanikapacit':
                    return $this->aktivniPlanovani(false, $rezimUprav);

                case 'planovanislotu':
                    return $this->aktivniPlanovani(true, $rezimUprav);
            }
        } catch (Exception $e) {
            MessageManager::addErrorMessage($e);
        }

        if ($action === 'kapacitydlesmen'  ||  $rezim === 3) {
            // prehled podle smen
            return $this ->kapacityDleSmen();
        }

        // pasivni zobrazeni
        HttpResponse::setCookieAndSession('kapacity_sort', 'kapacity_sort', false, true); // GET

        $viewObject = new PrehledKapacitView($this ->database);
        $viewObject ->load();

        return  $viewObject;
    }

}
